==> razo-18.0.0.tar.gz: razo-18.0.0/razo/__init__.py <==
import time
import sys
import datetime

rooting=False
sudoroot=False
nowsudo=False

def setting():
    a=input('Please set root password:')
    with open('settings.py','w') as c:
        c.write("rootpass='{}'\n".format('a'))
    a=input('What is your name?')
    with open('settings.py','a') as c:
        c.write("username='{}'\n".format(a))
    
def showinfo():
    listget={6:'Sun.',0:'Mon.',1:'Tue.',2:'Wed.',3:'Thu.',4:'Fri',5:'Sat.'}
    timer=datetime.datetime.now()
    weekday=listget[timer.weekday()]
    print(timer.strftime('%Y-%m-%d %H:%M:%S')+' {}'.format(weekday) )
    print('Razo 18.0.0(turtle_9).')
    print('Type help for help.')
    print('Still testing,please know.')


h=(
'''
help:Show help.
su:Ask for superuser license.
shutdown:Shutdown razo.
info:Show info.
setting:Run setting.
time:Get time.
sudo(add before commands):Let the command after sudo get temp root.
''')




try:
    import settings
    d=settings.rootpass
    username=settings.username
except ImportError as e:
    setting()
    
def sc():
    global sudoroot
    if not sudoroot:
        a=input('Please enter root password:')
        import settings
        if a==settings.rootpass:
            sudoroot=True
            return True
        else:
            print('Sorry.')
            return False
    else:
        return True
    
def wai(a):
    global rooting
    global sudoroot
    global nowsudo
    if a=='help':
        print(h)
    elif a=='su':
        a=input('Please enter root password:')
        import settings
        if a==settings.rootpass:
            rooting=True
        else:
            time.sleep(2)
            print('su:Sorry')
    elif a=='shutdown':
        if rooting:
            yes=input('Do you REALLY want to shutdown?[y/n]')
            if yes=='y':
                print('Shutting down.')
                time.sleep(5)
                sys.exit(0)
        else:
            print('Not able until root.')
    elif a=='info':
        showinfo()
    elif a=='setting':
        if rooting:
            setting()
            rooting=False
        else:
            print('Not able until root.')
    elif a=='time':
        listget={6:'Sun.',0:'Mon.',1:'Tue.',2:'Wed.',3:'Thu.',4:'Fri',5:'Sat.'}
        timer=datetime.datetime.now()
        weekday=listget[timer.weekday()]
        print(timer.strftime('%Y-%m-%d %H:%M:%S')+' {}'.format(weekday) )
        #The line between usually and sudo.
    elif a=='sudo help':
        if sc():
            nowsudo=True
        print(h)
        nowsudo=False
    elif a=='sudo su':
        if sc():
            nowsudo=True
        a=input('Please enter root password:')
        import settings
        if a==settings.rootpass:
            rooting=True
        else:
            time.sleep(2)
            print('su:Sorry')
        nowsudo=False
    elif a=='sudo shutdown':
        if sc():
            nowsudo=True
        if nowsudo:
            yes=input('Do you REALLY want to shutdown?[y/n]')
            if yes=='y':
                print('Shutting down.')
                time.sleep(5)
                sys.exit(0)
        else:
            print('Not able until root.')
    elif a=='sudo info':
        if sc():
            nowsudo=True
        showinfo()
        nowsudo=False
    elif a=='sudo setting':
        if sc():
            nowsudo=True
        if nowsudo:
            setting()
            rooting=False
            sudoroot=False
            nowsudo=False
        else:
            print('Not able until root.')
    elif a=='sudo time':
        if sc():
            nowsudo=True
        listget={6:'Sun.',0:'Mon.',1:'Tue.',2:'Wed.',3:'Thu.',4:'Fri',5:'Sat.'}
        timer=datetime.datetime.now()
        weekday=listget[timer.weekday()]
        print(timer.strftime('%Y-%m-%d %H:%M:%S')+' {}'.format(weekday) )
        nowsudo=False
    else:
        print('No this command.')
    

showinfo()
time.sleep(2)
import settings
print('Hello,{}.'.format(settings.username))

while True:
    if rooting:
        a=input('[root]>>>')
    else:
        a=input('[user]>>>')
    wai(a)

==> razo-2022.55.0.0b2.tar.gz: razo-2022.55.0.0b2/razo/__init__.py <==
#coding=utf-8

import time
import sys
import datetime
from razo.langpack import pack

rooting=False
sudoroot=False
nowsudo=False

liense=pack[0]
def setting():
    print(pack[1])
    print(liense)
    a=input(pack[2])
    if a=='n':
        print(pack[3])
        time.sleep(5)
        sys.exit(0)
    with open('settings.py','w') as c:
        c.write('#coding=utf-8\n')
    a=input(pack[4])
    with open('settings.py','a') as c:
        c.write("rootpass={}\n".format(a.encode()))
    a=input(pack[5])
    with open('settings.py','a') as c:
        c.write("username='{}'\n".format(a))
    
def showinfo():
    listget=pack[13]
    timer=datetime.datetime.now()
    weekday=listget[timer.weekday()]
    print(timer.strftime(pack[14])+' {}'.format(weekday) )
    tdo=[]
    with open('razo_ver.txt') as res:
        a=res.read().split(' ')
    print('Razo {0}({1}).'.format(a[0],a[1]))
    print(pack[6])
    print(pack[7])


h=pack[8]




try:
    import settings
    d=settings.rootpass
    username=settings.username
except ImportError as e:
    setting()
    
def sc():
    global sudoroot
    if not sudoroot:
        a=input(pack[9])
        import settings
        if a==settings.rootpass.decode():
            sudoroot=True
            return True
        else:
            print(pack[18])
            return False
    else:
        return True
    
def wai(a):
    global rooting
    global sudoroot
    global nowsudo
    if a=='help':
        print(h)
    elif a=='su':
        a=input(pack[9])
        import settings
        if a==settings.rootpass.decode():
            rooting=True
        else:
            time.sleep(2)
            print(pack[10])
    elif a=='shutdown':
        if rooting:
            yes=input(pack[11])
            if yes=='y':
                print(pack[12])
                time.sleep(5)
                sys.exit(0)
        else:
            print(pack[15])
    elif a=='info':
        showinfo()
    elif a=='setting':
        if rooting:
            setting()
            rooting=False
        else:
            print(pack[15])
    elif a=='time':
        listget=pack[13]
        timer=datetime.datetime.now()
        weekday=listget[timer.weekday()]
        print(timer.strftime(pack[14])+' {}'.format(weekday) )
        #The line between usually and sudo.
    elif a=='sudo help':
        if sc():
            nowsudo=True
        print(h)
        nowsudo=False
    elif a=='sudo su':
        if sc():
            nowsudo=True
        a=input('Please enter root password:')
        import settings
        if a==settings.rootpass:
            rooting=True
        else:
            time.sleep(2)
            print('su:Sorry')
        nowsudo=False
    elif a=='sudo shutdown':
        if sc():
            nowsudo=True
        if nowsudo:
            yes=input(pack[11])
            if yes=='y':
                print(pack[12])
                time.sleep(5)
                sys.exit(0)
        else:
            print(pack[15])
    elif a=='sudo info':
        if sc():
            nowsudo=True
        showinfo()
        nowsudo=False
    elif a=='sudo setting':
        if sc():
            nowsudo=True
        if nowsudo:
            setting()
            rooting=False
            sudoroot=False
            nowsudo=False
        else:
            print(pack[15])
    elif a=='sudo time':
        if sc():
            nowsudo=True
        listget=pack[13]
        timer=datetime.datetime.now()
        weekday=listget[timer.weekday()]
        print(timer.strftime(pack[14])+' {}'.format(weekday) )
        nowsudo=False
    else:
        try:
            exec('import '+a)
        except (ImportError,SyntaxError) as exc:
            try:
                if sc():
                    nowsudo=True
                exec('import '+a[5:])
                nowsudo=False
            except (ImportError,SyntaxError) as exc:
                print(pack[16].format(a))
    

showinfo()
time.sleep(2)
import settings
print(pack[17].format(settings.username))

while True:
    if rooting:
        a=input('[root]>>>')
    else:
        a=input('[user]>>>')
    wai(a)
